@@ -36,5 +36,5 @@ def main(args=None):
     shutil.copy(source, destination)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     main()
